---
title: Plotter Tab
page_id: plotter_tab
sort_order: 3
---

The plotter tab can be used to visualize data logged from the Crazyflie.

![cfclient plotter](/docs/images/cfclient_plotter.png)

1.  Select logging configuration to plot. Read about how to create
    configurations [here](/docs/userguides/userguide_client/#logging).
2.  Legend for the logging configuration that is being plotted.
3.  Logged data, zooming and panning can be done with the mouse.
4.  X-axis manipulation. Either a custom time range, a number of samples, or number of seconds can be used. If number of samples or seconds is used, the plot fills up the window and will start scrolling the data.
5.  Auto-scaling or fixed scaling for the Y-axis
6.  Auto update graph. If this is disabled the plot will stop updating
    (but data will still be collected in the background)
